You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by ms...@apache.org on 2020/08/22 12:27:06 UTC

[openoffice] branch AOO42X updated: Fixed typos (internaly -> internally) and some more

This is an automated email from the ASF dual-hosted git repository.

mseidel pushed a commit to branch AOO42X
in repository https://gitbox.apache.org/repos/asf/openoffice.git


The following commit(s) were added to refs/heads/AOO42X by this push:
     new a49f191  Fixed typos (internaly -> internally) and some more
a49f191 is described below

commit a49f1911595c204417747a13c46de0781bf1eb5b
Author: mseidel <ms...@apache.org>
AuthorDate: Sat Aug 22 14:24:38 2020 +0200

    Fixed typos (internaly -> internally) and some more
    
    (cherry picked from commit 06fea5eb2b9aa5023a47343a2dfc561c5943149a)
---
 main/comphelper/inc/comphelper/numberedcollection.hxx      |  2 +-
 main/comphelper/inc/comphelper/sequenceashashmap.hxx       |  2 +-
 main/filter/source/config/cache/contenthandlerfactory.hxx  |  4 ++--
 main/filter/source/config/cache/filtercache.hxx            |  2 +-
 main/filter/source/config/cache/filterfactory.hxx          |  2 +-
 main/filter/source/config/cache/frameloaderfactory.hxx     |  4 ++--
 main/filter/source/config/cache/typedetection.hxx          |  4 ++--
 .../win32/filepicker/VistaFilePickerEventHandler.hxx       |  8 ++++----
 .../source/win32/filepicker/VistaFilePickerImpl.hxx        | 14 +++++++-------
 main/fpicker/source/win32/filepicker/asyncrequests.hxx     |  2 +-
 main/framework/inc/classes/propertysethelper.hxx           |  2 +-
 main/framework/inc/dispatch/closedispatcher.hxx            | 14 +++++++-------
 main/framework/inc/dispatch/dispatchprovider.hxx           |  2 +-
 main/framework/inc/dispatch/startmoduledispatcher.hxx      |  2 +-
 .../inc/framework/preventduplicateinteraction.hxx          |  4 ++--
 main/framework/inc/framework/titlehelper.hxx               |  4 ++--
 main/framework/inc/helper/statusindicatorfactory.hxx       |  2 +-
 main/framework/inc/interaction/quietinteraction.hxx        | 10 +++++-----
 main/framework/inc/loadstate.h                             |  2 +-
 main/framework/inc/recording/dispatchrecordersupplier.hxx  |  2 +-
 main/framework/inc/services/autorecovery.hxx               | 14 +++++++-------
 main/framework/inc/services/desktop.hxx                    |  4 ++--
 main/framework/inc/services/detectorfactory.hxx            |  4 ++--
 main/framework/inc/services/pathsettings.hxx               |  2 +-
 .../qa/complex/loadAllDocuments/CheckXComponentLoader.java |  4 ++--
 main/framework/source/dispatch/mailtodispatcher.cxx        |  4 ++--
 main/framework/source/fwe/helper/titlehelper.cxx           |  6 +++---
 .../source/inc/accelerators/acceleratorconfiguration.hxx   |  2 +-
 .../inc/accelerators/documentacceleratorconfiguration.hxx  |  2 +-
 .../inc/accelerators/globalacceleratorconfiguration.hxx    |  2 +-
 .../inc/accelerators/moduleacceleratorconfiguration.hxx    |  2 +-
 main/framework/source/inc/accelerators/presethandler.hxx   |  8 ++++----
 main/framework/source/inc/loadenv/loadenv.hxx              |  6 +++---
 main/framework/source/jobs/jobresult.cxx                   |  4 ++--
 main/framework/source/loadenv/loadenv.cxx                  |  4 ++--
 .../source/recording/dispatchrecordersupplier.cxx          |  2 +-
 main/framework/source/services/autorecovery.cxx            |  6 +++---
 main/framework/source/services/backingcomp.cxx             |  2 +-
 main/framework/source/services/frame.cxx                   |  4 ++--
 main/framework/source/services/modulemanager.cxx           |  4 ++--
 .../OfficeDev/DesktopEnvironment/CustomizeView.java        |  4 ++--
 .../OfficeDev/DesktopEnvironment/StatusListener.java       |  2 +-
 .../OfficeDev/DesktopEnvironment/StatusView.java           |  2 +-
 main/offapi/com/sun/star/document/FilterFactory.idl        |  2 +-
 .../offapi/com/sun/star/frame/DispatchRecorderSupplier.idl |  2 +-
 .../com/sun/star/frame/XDispatchRecorderSupplier.idl       |  4 ++--
 main/sd/inc/Outliner.hxx                                   |  2 +-
 main/sfx2/source/appl/sfxhelp.cxx                          |  2 +-
 main/svtools/inc/svtools/filectrl.hxx                      |  2 +-
 main/svx/source/inc/svxrectctaccessiblecontext.hxx         |  4 ++--
 main/svx/source/unodraw/recoveryui.cxx                     |  2 +-
 51 files changed, 101 insertions(+), 101 deletions(-)

diff --git a/main/comphelper/inc/comphelper/numberedcollection.hxx b/main/comphelper/inc/comphelper/numberedcollection.hxx
index ef65459..b4f8808 100644
--- a/main/comphelper/inc/comphelper/numberedcollection.hxx
+++ b/main/comphelper/inc/comphelper/numberedcollection.hxx
@@ -94,7 +94,7 @@ class COMPHELPER_DLLPUBLIC NumberedCollection : private ::cppu::BaseMutex
         NumberedCollection();
         
         //---------------------------------------
-        /** @short  free all internaly used resources.
+        /** @short  free all internally used resources.
          */                    
         virtual ~NumberedCollection();
     
diff --git a/main/comphelper/inc/comphelper/sequenceashashmap.hxx b/main/comphelper/inc/comphelper/sequenceashashmap.hxx
index b8cfb49..12afefc 100644
--- a/main/comphelper/inc/comphelper/sequenceashashmap.hxx
+++ b/main/comphelper/inc/comphelper/sequenceashashmap.hxx
@@ -301,7 +301,7 @@ class COMPHELPER_DLLPUBLIC SequenceAsHashMap : public SequenceAsHashMapBase
             @param  aValue
                     the new (unpacked!) value.
                     Note: This value will be transformed to an Any
-                    internaly, because only Any values can be
+                    internally, because only Any values can be
                     part of a PropertyValue or NamedValue structure.
 
             @return TRUE if this property was added as new item;
diff --git a/main/filter/source/config/cache/contenthandlerfactory.hxx b/main/filter/source/config/cache/contenthandlerfactory.hxx
index d19e6e1..afb7fa0 100644
--- a/main/filter/source/config/cache/contenthandlerfactory.hxx
+++ b/main/filter/source/config/cache/contenthandlerfactory.hxx
@@ -129,9 +129,9 @@ class ContentHandlerFactory : public ::cppu::ImplInheritanceHelper1< BaseContain
                     a new instance of this service if needed.
 
             @param  xSMGR
-                    reference to the uno service manager, which require
+                    reference to the uno service manager, which requires
                     this new instance. It should be passed to the new object
-                    so it can be used internaly to create own needed uno resources.
+                    so it can be used internally to create own needed uno resources.
 
             @return The new instance of this service as an uno reference.
          */
diff --git a/main/filter/source/config/cache/filtercache.hxx b/main/filter/source/config/cache/filtercache.hxx
index f14fc5e..ad7e2c6 100644
--- a/main/filter/source/config/cache/filtercache.hxx
+++ b/main/filter/source/config/cache/filtercache.hxx
@@ -567,7 +567,7 @@ class FilterCache : public BaseLock
 
             @attention  These properties are not part of the normal CacheItem
                         returned by the method getItem(). Because getItem() is
-                        used internaly too but these specialized properties
+                        used internally too but these specialized properties
                         are needed at our container services only. So these
                         function sets are different to allow different handling.
 
diff --git a/main/filter/source/config/cache/filterfactory.hxx b/main/filter/source/config/cache/filterfactory.hxx
index 9e6aa3b..81e758d 100644
--- a/main/filter/source/config/cache/filterfactory.hxx
+++ b/main/filter/source/config/cache/filterfactory.hxx
@@ -195,7 +195,7 @@ class FilterFactory : public ::cppu::ImplInheritanceHelper1< BaseContainer
             @param  xSMGR
                     reference to the uno service manager, which require
                     this new instance. It should be passed to the new object
-                    so it can be used internaly to create own needed uno resources.
+                    so it can be used internally to create own needed uno resources.
 
             @return The new instance of this service as an uno reference.
          */
diff --git a/main/filter/source/config/cache/frameloaderfactory.hxx b/main/filter/source/config/cache/frameloaderfactory.hxx
index d98a807..3107c35 100644
--- a/main/filter/source/config/cache/frameloaderfactory.hxx
+++ b/main/filter/source/config/cache/frameloaderfactory.hxx
@@ -129,9 +129,9 @@ class FrameLoaderFactory : public ::cppu::ImplInheritanceHelper1< BaseContainer
                     a new instance of this service if needed.
 
             @param  xSMGR
-                    reference to the uno service manager, which require
+                    reference to the uno service manager, which requires
                     this new instance. It should be passed to the new object
-                    so it can be used internaly to create own needed uno resources.
+                    so it can be used internally to create own needed uno resources.
 
             @return The new instance of this service as an uno reference.
          */
diff --git a/main/filter/source/config/cache/typedetection.hxx b/main/filter/source/config/cache/typedetection.hxx
index a8851a8..5ddf934 100644
--- a/main/filter/source/config/cache/typedetection.hxx
+++ b/main/filter/source/config/cache/typedetection.hxx
@@ -440,9 +440,9 @@ class TypeDetection : public ::cppu::ImplInheritanceHelper1< BaseContainer
                     a new instance of this service if needed.
 
             @param  xSMGR
-                    reference to the uno service manager, which require
+                    reference to the uno service manager, which requires
                     this new instance. It should be passed to the new object
-                    so it can be used internaly to create own needed uno resources.
+                    so it can be used internally to create own needed uno resources.
 
             @return The new instance of this service as an uno reference.
          */
diff --git a/main/fpicker/source/win32/filepicker/VistaFilePickerEventHandler.hxx b/main/fpicker/source/win32/filepicker/VistaFilePickerEventHandler.hxx
index eec8b55..e2ba8a5 100644
--- a/main/fpicker/source/win32/filepicker/VistaFilePickerEventHandler.hxx
+++ b/main/fpicker/source/win32/filepicker/VistaFilePickerEventHandler.hxx
@@ -145,7 +145,7 @@ class VistaFilePickerEventHandler : public ::cppu::BaseMutex
         //------------------------------------------------------------------------------------
         /** start listening for file picker events on the given file open dialog COM object.
          *
-         *  The broadcaster will be cached internaly so deregistration will be easy.
+         *  The broadcaster will be cached internally so deregistration will be easy.
          *  Further all needed informations are capsulated within this class (e.g. the listener handler).
          *  Nobody outside must know such informations.
          *
@@ -158,10 +158,10 @@ class VistaFilePickerEventHandler : public ::cppu::BaseMutex
         void startListening( const TFileDialog& pBroadcaster );
         
         //------------------------------------------------------------------------------------
-        /** stop listening for file picker events on the internaly cached dialog COM object.
+        /** stop listening for file picker events on the internally cached dialog COM object.
          *
-         *  The  COM dialog provided on the startListeneing() call was cached internaly.
-         *  And now its used to deregister this listener. Doing so the also internaly cached
+         *  The  COM dialog provided on the startListeneing() call was cached internally.
+         *  And now its used to deregister this listener. Doing so the also internally cached
          *  listener handle is used. If listener was not already registered - nothing will happen.
          */
         void stopListening();
diff --git a/main/fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx b/main/fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx
index d9640b6..f653b7e 100644
--- a/main/fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx
+++ b/main/fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx
@@ -110,8 +110,8 @@ static const ::rtl::OUString PROP_CONTROL_ENABLE      = ::rtl::OUString::createF
 static const ::rtl::OUString STRING_SEPARATOR         = ::rtl::OUString::createFromAscii("------------------------------------------" );
 
 //-----------------------------------------------------------------------------
-/** native implementation of the file picker on Vista and upcoming windows versions.
- *  This dialog uses COM internaly. Further it marshall every request so it will
+/** native implementation of the file picker on Vista and upcoming Windows versions.
+ *  This dialog uses COM internally. Further it marshall every request so it will
  *  be executed within it's own STA thread !
  */
 //-----------------------------------------------------------------------------
@@ -280,11 +280,11 @@ class VistaFilePickerImpl : private ::cppu::BaseMutex
 		void impl_sta_enableFeatures(::sal_Int32 nFeatures, ::sal_Int32 nTemplate);
     
         //---------------------------------------------------------------------
-        /** returns an interface, which can be used to customize the internaly used
+        /** returns an interface, which can be used to customize the internally used
          *  COM dialog.
          *
-         *  Because we use two member (open/save dialog) internaly, this method
-         *  ask the current active one for it's customization interface.
+         *  Because we use two members (open/save dialog) internally, this method
+         *  asks the current active one for its customization interface.
          *
          *  @return the customization interface for the current used dialog.
          *          Must not be null.
@@ -318,8 +318,8 @@ class VistaFilePickerImpl : private ::cppu::BaseMutex
    
         //---------------------------------------------------------------------
         /** cache last selected list of files
-         *  Because those list must be retrieved directly after closing the dialog
-         *  (and only in case it was finished successfully) we cache it internaly.
+         *  Because those lists must be retrieved directly after closing the dialog
+         *  (and only in case it was finished successfully) we cache it internally.
          *  Because the outside provided UNO API decouple showing the dialog
          *  and asking for results .-)
          */
diff --git a/main/fpicker/source/win32/filepicker/asyncrequests.hxx b/main/fpicker/source/win32/filepicker/asyncrequests.hxx
index 32ee8a3..ad9b903 100644
--- a/main/fpicker/source/win32/filepicker/asyncrequests.hxx
+++ b/main/fpicker/source/win32/filepicker/asyncrequests.hxx
@@ -201,7 +201,7 @@ class AsyncRequests : private ::cppu::BaseMutex
         
         //---------------------------------------------------------------------
         /** our STA .-)
-         *  Will run between start() & finish(). Internaly it runs a loop ... 
+         *  Will run between start() & finish(). Internally it runs a loop ... 
          *  waiting for requests. Every request will be executed synchronously
          *  in blocked mode.
          */
diff --git a/main/framework/inc/classes/propertysethelper.hxx b/main/framework/inc/classes/propertysethelper.hxx
index 16a13de..248c779 100644
--- a/main/framework/inc/classes/propertysethelper.hxx
+++ b/main/framework/inc/classes/propertysethelper.hxx
@@ -99,7 +99,7 @@ class FWI_DLLPUBLIC PropertySetHelper : public css::beans::XPropertySet
         /** initialize new instance of this helper.
          *
          *  @param  xSMGR
-         *          points to an uno service manager, which is used internaly to create own
+         *          points to an uno service manager, which is used internally to create own
          *          needed uno services.
          *
          *  @param  pExternalLock
diff --git a/main/framework/inc/dispatch/dispatchprovider.hxx b/main/framework/inc/dispatch/dispatchprovider.hxx
index 77f0405..bc747b4 100644
--- a/main/framework/inc/dispatch/dispatchprovider.hxx
+++ b/main/framework/inc/dispatch/dispatchprovider.hxx
@@ -67,7 +67,7 @@ namespace framework{
 
 /**
     @descr          We know some special dispatch objects with different functionality.
-                    The can be created internaly by the following DispatchProvider.
+                    They can be created internally by the following DispatchProvider.
                     Here we define some identifier to force creation of the right one.
 */
 enum EDispatchHelper
diff --git a/main/framework/inc/dispatch/startmoduledispatcher.hxx b/main/framework/inc/dispatch/startmoduledispatcher.hxx
index 90c465f..b4f47cc 100644
--- a/main/framework/inc/dispatch/startmoduledispatcher.hxx
+++ b/main/framework/inc/dispatch/startmoduledispatcher.hxx
@@ -103,7 +103,7 @@ class StartModuleDispatcher : public css::lang::XTypeProvider
 
             @param  xSMGR
                     an uno service manager, which is needed to create uno resource
-                    internaly.
+                    internally.
 
             @param  xFrame
                     the frame where the corresponding dispatch was started.
diff --git a/main/framework/inc/framework/preventduplicateinteraction.hxx b/main/framework/inc/framework/preventduplicateinteraction.hxx
index 0462e33..005a3fc 100644
--- a/main/framework/inc/framework/preventduplicateinteraction.hxx
+++ b/main/framework/inc/framework/preventduplicateinteraction.hxx
@@ -187,7 +187,7 @@ class FWE_DLLPUBLIC PreventDuplicateInteraction : private ThreadHelpBase2
                         generic UI interaction handler for later internal using.
 
             @param      xSMGR
-                            uno service manager for creating services internaly
+                            uno service manager for creating services internally
 
             @threadsafe not necessary
         */
@@ -201,7 +201,7 @@ class FWE_DLLPUBLIC PreventDuplicateInteraction : private ThreadHelpBase2
 
         //_________________________________
         /**
-            @short      set the outside interaction handler, which must be used internaly
+            @short      set the outside interaction handler, which must be used internally
                         if the interaction will not be blocked by the set list of rules.
 
             @note       This overwrites the settings of e.g. useDefaultUUIHandler()!
diff --git a/main/framework/inc/framework/titlehelper.hxx b/main/framework/inc/framework/titlehelper.hxx
index bb2fa76..eb6ebe0 100644
--- a/main/framework/inc/framework/titlehelper.hxx
+++ b/main/framework/inc/framework/titlehelper.hxx
@@ -84,7 +84,7 @@ class FWE_DLLPUBLIC TitleHelper : private ::cppu::BaseMutex
         TitleHelper(const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR);
 
         //---------------------------------------
-        /** @short  free all internaly used resources.
+        /** @short  free all internally used resources.
          */
         virtual ~TitleHelper();
 
@@ -201,7 +201,7 @@ class FWE_DLLPUBLIC TitleHelper : private ::cppu::BaseMutex
         /** provides parts of our own title and we listen there for changes too. */
         css::uno::WeakReference< css::frame::XTitle > m_xSubTitle;
 
-        /** if it's set to sal_True the member m_sTitle has not to be changed internaly.
+        /** if it's set to sal_True the member m_sTitle has not to be changed internally.
             It was set from outside and so outside code has to make sure it will be
             updated.
          */
diff --git a/main/framework/inc/helper/statusindicatorfactory.hxx b/main/framework/inc/helper/statusindicatorfactory.hxx
index fdeba21..e1d536a 100644
--- a/main/framework/inc/helper/statusindicatorfactory.hxx
+++ b/main/framework/inc/helper/statusindicatorfactory.hxx
@@ -159,7 +159,7 @@ typedef ::std::vector< IndicatorInfo > IndicatorStack;
 //===============================================
 /** @short          implement a factory service to create new status indicator objects
 
-    @descr			Internaly it uses:
+    @descr			Internally it uses:
                     - a vcl based
                     - or an uno based and by the frame layouted
                     progress implementation.
diff --git a/main/framework/inc/interaction/quietinteraction.hxx b/main/framework/inc/interaction/quietinteraction.hxx
index 43f9750..1fa936a 100644
--- a/main/framework/inc/interaction/quietinteraction.hxx
+++ b/main/framework/inc/interaction/quietinteraction.hxx
@@ -127,10 +127,10 @@ class QuietInteraction : public  css::lang::XTypeProvider
 
         //_________________________________
         /**
-            @short      return the handled interaction request
-            @descr      We saved any getted interaction request internaly.
-                        May the outside user of this class is interessted
-                        on that. Especially we gotted an unknown interaction
+            @short      returns the handled interaction request
+            @descr      We saved any getted interaction request internally.
+                        Maybe the outside user of this class is interested
+                        in that. Especially if we got an unknown interaction
                         and aborted it hard.
 
             @return     [com.sun.star.uno.Any]
@@ -144,7 +144,7 @@ class QuietInteraction : public  css::lang::XTypeProvider
         //_________________________________
         /**
             @short      returns information if interaction was used
-            @descr      It can be usefully to know the reason for a failed operation.
+            @descr      It can be useful to know the reason for a failed operation.
 
             @return     [boolean]
                             <TRUE/> for used interaction
diff --git a/main/framework/inc/loadstate.h b/main/framework/inc/loadstate.h
index 978733a..6f05d66 100644
--- a/main/framework/inc/loadstate.h
+++ b/main/framework/inc/loadstate.h
@@ -47,7 +47,7 @@ enum ELoadState
 {
     E_UNSPECIFIED   =   0,  // indicates the operation was not already started
     E_SUCCESS       =   1,  // the load request was successful
-    E_IOERROR       =   2,  // there was an io error internaly
+    E_IOERROR       =   2,  // there was an io error internally
     E_INTERACTION   =   3,  // there was an interaction, which couldn't be handled (doesn't include IO interactions => see E_IOERROR before)
     E_FAILED        =   4   // for unknown or unspecified errors
 };
diff --git a/main/framework/inc/recording/dispatchrecordersupplier.hxx b/main/framework/inc/recording/dispatchrecordersupplier.hxx
index 23c14f9..20ec58d 100644
--- a/main/framework/inc/recording/dispatchrecordersupplier.hxx
+++ b/main/framework/inc/recording/dispatchrecordersupplier.hxx
@@ -87,7 +87,7 @@ class DispatchRecorderSupplier  :   // interfaces
         /** provided dispatch recorder of this supplier instance
 
             @life   Is controlled from outside. Because this variable is set
-                    from there and not created internaly. But we release our
+                    from there and not created internally. But we release our
                     reference to it if we die.
          */
         css::uno::Reference< css::frame::XDispatchRecorder > m_xDispatchRecorder;
diff --git a/main/framework/inc/services/autorecovery.hxx b/main/framework/inc/services/autorecovery.hxx
index 794dab3..2e7d933 100644
--- a/main/framework/inc/services/autorecovery.hxx
+++ b/main/framework/inc/services/autorecovery.hxx
@@ -399,17 +399,17 @@ class AutoRecovery  : public  css::lang::XTypeProvider
 
         /** @descr  This member is used to prevent us against re-entrance problems.
                     A mutex can't help to prevent us from concurrent using of members
-                    inside the same thread. But e.g. our internaly used stl structures
+                    inside the same thread. But e.g. our internally used stl structures
                     are not threadsafe ... and furthermore they can't be used at the same time
                     for iteration and add/remove requests!
                     So we have to detect such states and ... show a warning.
                     May be there will be a better solution next time ... (copying the cache temp.
-                    bevor using).
+                    before using).
 
                     And further it's not possible to use a simple boolean value here.
-                    Because if more then one operation iterates over the same stl container ...
-                    (only to modify it's elements but dont add new or removing existing ones!)
-                    it should be possible doing so. But we must guarantee that the last operation reset
+                    Because if more than one operation iterates over the same stl container ...
+                    (only to modify its elements but don't add new or removing existing ones!)
+                    it should be possible doing so. But we must guarantee that the last operation resets
                     this lock ... not the first one ! So we use a "ref count" mechanism for that."
          */
         sal_Int32 m_nDocCacheLock;
@@ -466,8 +466,8 @@ class AutoRecovery  : public  css::lang::XTypeProvider
         // css.document.XEventListener
         /** @short  informs about created/opened documents.
 
-            @descr  Every new opened/created document will be saved internaly
-                    so it can be checked if its modified. This modified state
+            @descr  Every new opened/created document will be saved internally
+                    so it can be checked if it's modified. This modified state
                     is used later to decide, if it must be saved or not.
 
             @param  aEvent
diff --git a/main/framework/inc/services/desktop.hxx b/main/framework/inc/services/desktop.hxx
index 03e5bee..677869d 100644
--- a/main/framework/inc/services/desktop.hxx
+++ b/main/framework/inc/services/desktop.hxx
@@ -476,8 +476,8 @@ class Desktop   :   // interfaces
 
         //---------------------------------------------------------------------
         /** special terminate listener which loads images asynchronous for current open documents.
-          * Because internaly it uses blocking system APIs ... it can't be guaranteed that
-          * running jobs can be cancelled successfully if the corressponding document will be closed ...
+          * Because internally it uses blocking system APIs ... it can't be guaranteed that
+          * running jobs can be cancelled successfully if the corresponding document will be closed ...
           * it will not hinder those documents on closing. Instead it let all jobs running ...
           * but at least on terminate we have to wait for all those blocked requests.
           * So these implementation must be a special terminate listener too .-(
diff --git a/main/framework/inc/services/detectorfactory.hxx b/main/framework/inc/services/detectorfactory.hxx
index 597277d..f418743 100644
--- a/main/framework/inc/services/detectorfactory.hxx
+++ b/main/framework/inc/services/detectorfactory.hxx
@@ -327,8 +327,8 @@ class DetectorFactory : // interfaces
             @param  sName
                     the uno implementation name the requested detector.
 
-            @return A property set, which describe this detect service.
-                    It uses a sequence< com::sun::star::beans::PropertyValue > internaly.
+            @return A property set, which describes this detect service.
+                    It uses a sequence< com::sun::star::beans::PropertyValue > internally.
 
             @exception  com::sun::star::container::NoSuchElementException
                         if the requested entry does not exist inside this container.
diff --git a/main/framework/inc/services/pathsettings.hxx b/main/framework/inc/services/pathsettings.hxx
index caf9691..2b5eb16 100644
--- a/main/framework/inc/services/pathsettings.hxx
+++ b/main/framework/inc/services/pathsettings.hxx
@@ -104,7 +104,7 @@ class PathSettings : public  css::lang::XTypeProvider             ,
             /// an internal name describing this path
             ::rtl::OUString sPathName;
 
-            /// contains all paths, which are used internaly - but are not visible for the user.
+            /// contains all paths, which are used internally - but are not visible for the user.
             OUStringList lInternalPaths;
 
             /// contains all paths configured by the user
diff --git a/main/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java b/main/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java
index b8d34c1..0a12b77 100644
--- a/main/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java
+++ b/main/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java
@@ -285,8 +285,8 @@ public class CheckXComponentLoader
                   )
             {
                 loadURL(m_xLoader, RESULT_VALID_DOC, sURL, "_blank", 0, lProps);
-                // Its not needed to reset this using states!
-                // Its done internaly ...
+                // It's not needed to reset this using states!
+                // It's done internally ...
                 if (!xIndicator.wasUsed())
                 {
                     System.out.println("External progress was not used for loading.");
diff --git a/main/framework/source/dispatch/mailtodispatcher.cxx b/main/framework/source/dispatch/mailtodispatcher.cxx
index d0334bf..51d302a 100644
--- a/main/framework/source/dispatch/mailtodispatcher.cxx
+++ b/main/framework/source/dispatch/mailtodispatcher.cxx
@@ -182,8 +182,8 @@ css::uno::Sequence< css::uno::Reference< css::frame::XDispatch > > SAL_CALL Mail
 /**
     @short      dispatch URL with arguments
     @descr      We use threadsafe internal method to do so. It returns a state value - but we ignore it.
-                Because we doesn't support status listener notifications here. Status events are not guaranteed -
-                and we call another service internaly which doesn't return any notifications too.
+                Because we don't support status listener notifications here. Status events are not guaranteed -
+                and we call another service internally which doesn't return any notifications too.
 
     @param      aURL
                     mail URL which should be executed
diff --git a/main/framework/source/fwe/helper/titlehelper.cxx b/main/framework/source/fwe/helper/titlehelper.cxx
index 50bcaa4..3227b89 100644
--- a/main/framework/source/fwe/helper/titlehelper.cxx
+++ b/main/framework/source/fwe/helper/titlehelper.cxx
@@ -354,7 +354,7 @@ void TitleHelper::impl_updateTitleForModel (const css::uno::Reference< css::fram
     // SYNCHRONIZED ->
     ::osl::ResettableMutexGuard aLock(m_aMutex);
     
-        // external title wont be updated internaly !
+        // external title won't be updated internally !
         // It has to be set from outside new.
         if (m_bExternalTitle)
             return;
@@ -425,7 +425,7 @@ void TitleHelper::impl_updateTitleForController (const css::uno::Reference< css:
     // SYNCHRONIZED ->
     ::osl::ResettableMutexGuard aLock(m_aMutex);
     
-        // external title wont be updated internaly !
+        // external title won't be updated internally !
         // It has to be set from outside new.
         if (m_bExternalTitle)
             return;
@@ -494,7 +494,7 @@ void TitleHelper::impl_updateTitleForFrame (const css::uno::Reference< css::fram
     // SYNCHRONIZED ->
     ::osl::ResettableMutexGuard aLock(m_aMutex);
     
-        // external title wont be updated internaly !
+        // external title won't be updated internally !
         // It has to be set from outside new.
         if (m_bExternalTitle)
             return;
diff --git a/main/framework/source/inc/accelerators/acceleratorconfiguration.hxx b/main/framework/source/inc/accelerators/acceleratorconfiguration.hxx
index 4f19119..460c549 100644
--- a/main/framework/source/inc/accelerators/acceleratorconfiguration.hxx
+++ b/main/framework/source/inc/accelerators/acceleratorconfiguration.hxx
@@ -286,7 +286,7 @@ class XMLBasedAcceleratorConfiguration : protected ThreadHelpBase
 		/** @short  returns a reference to one of our internal cache members.
 
 		@descr  We implement the copy-on-write pattern. Doing so
-		we know two caches internaly. The second one is used
+		we know two caches internally. The second one is used
 		only, if the container was changed.
 
 		This method here returns access to one of these
diff --git a/main/framework/source/inc/accelerators/documentacceleratorconfiguration.hxx b/main/framework/source/inc/accelerators/documentacceleratorconfiguration.hxx
index 278535b..47a7d09 100644
--- a/main/framework/source/inc/accelerators/documentacceleratorconfiguration.hxx
+++ b/main/framework/source/inc/accelerators/documentacceleratorconfiguration.hxx
@@ -78,7 +78,7 @@ class DocumentAcceleratorConfiguration : public XMLBasedAcceleratorConfiguration
         /** initialize this instance and fill the internal cache.
         
             @param  xSMGR
-                    reference to an uno service manager, which is used internaly.
+                    reference to an uno service manager, which is used internally.
          */
         DocumentAcceleratorConfiguration(const css::uno::Reference< css::lang::XMultiServiceFactory > xSMGR);
         virtual ~DocumentAcceleratorConfiguration();
diff --git a/main/framework/source/inc/accelerators/globalacceleratorconfiguration.hxx b/main/framework/source/inc/accelerators/globalacceleratorconfiguration.hxx
index 8e06fce..5caf29c 100644
--- a/main/framework/source/inc/accelerators/globalacceleratorconfiguration.hxx
+++ b/main/framework/source/inc/accelerators/globalacceleratorconfiguration.hxx
@@ -70,7 +70,7 @@ class GlobalAcceleratorConfiguration : public XCUBasedAcceleratorConfiguration
         /** initialize this instance and fill the internal cache.
         
             @param  xSMGR
-                    reference to an uno service manager, which is used internaly.
+                    reference to an uno service manager, which is used internally.
          */
         GlobalAcceleratorConfiguration(const css::uno::Reference< css::lang::XMultiServiceFactory > xSMGR);
         
diff --git a/main/framework/source/inc/accelerators/moduleacceleratorconfiguration.hxx b/main/framework/source/inc/accelerators/moduleacceleratorconfiguration.hxx
index b98eee3..8e35a32 100644
--- a/main/framework/source/inc/accelerators/moduleacceleratorconfiguration.hxx
+++ b/main/framework/source/inc/accelerators/moduleacceleratorconfiguration.hxx
@@ -78,7 +78,7 @@ class ModuleAcceleratorConfiguration : public XCUBasedAcceleratorConfiguration
         /** initialize this instance and fill the internal cache.
         
             @param  xSMGR
-                    reference to an uno service manager, which is used internaly.
+                    reference to an uno service manager, which is used internally.
          */
         ModuleAcceleratorConfiguration(const css::uno::Reference< css::lang::XMultiServiceFactory > xSMGR);
         
diff --git a/main/framework/source/inc/loadenv/loadenv.hxx b/main/framework/source/inc/loadenv/loadenv.hxx
index 87f2363..576bc24 100644
--- a/main/framework/source/inc/loadenv/loadenv.hxx
+++ b/main/framework/source/inc/loadenv/loadenv.hxx
@@ -235,8 +235,8 @@ class LoadEnv : private ThreadHelpBase
         /** @short  initialize a new instance of this load environment.
 
             @param  xSMGR
-                    reference to an uno service manager, which can be used internaly
-                    to create on needed services on demand.
+                    reference to an uno service manager, which can be used internally
+                    to create own needed services on demand.
 
             @throw  Currently there is no reason to throw such exception!
 
@@ -518,7 +518,7 @@ class LoadEnv : private ThreadHelpBase
             @return [string]
                     the type selected by the user.
 
-            @attention  Internaly we update the member m_lMediaDescriptor!
+            @attention  Internally we update the member m_lMediaDescriptor!
          */
         ::rtl::OUString impl_askUserForTypeAndFilterIfAllowed()
             throw(LoadEnvException, css::uno::RuntimeException);
diff --git a/main/framework/source/jobs/jobresult.cxx b/main/framework/source/jobs/jobresult.cxx
index c652f83..c1ed864 100644
--- a/main/framework/source/jobs/jobresult.cxx
+++ b/main/framework/source/jobs/jobresult.cxx
@@ -178,7 +178,7 @@ JobResult::JobResult( const JobResult& rCopy )
 //________________________________
 /**
     @short      standard dtor
-    @descr      Free all internaly used ressources at the end of living.
+    @descr      Free all internally used resources at the end of living.
 */
 JobResult::~JobResult()
 {
@@ -215,7 +215,7 @@ void JobResult::operator=( const JobResult& rCopy )
                 by using our other members!
 
     @param      eParts
-                    a flag mask too, which will be compared with our internaly set one.
+                    a flag mask too, which will be compared with our internally set one.
 
     @return     We return true only, if any set flag of the given mask match.
 */
diff --git a/main/framework/source/loadenv/loadenv.cxx b/main/framework/source/loadenv/loadenv.cxx
index a516b1a..54d45cc 100644
--- a/main/framework/source/loadenv/loadenv.cxx
+++ b/main/framework/source/loadenv/loadenv.cxx
@@ -282,7 +282,7 @@ void LoadEnv::initializeLoading(const ::rtl::OUString&
 
     // try to find out, if its really a content, which can be loaded or must be "handled"
     // We use a default value for this in-parameter. Then we have to start a complex check method
-    // internaly. But if this check was already done outside it can be suppressed to perform
+    // internally. But if this check was already done outside it can be suppressed to perform
     // the load request. We take over the result then!
     if (m_eContentType == E_UNSUPPORTED_CONTENT)
     {
@@ -1452,7 +1452,7 @@ css::uno::Reference< css::frame::XFrame > LoadEnv::impl_searchAlreadyLoaded()
     if (xResult.is())
     {
         // Now we are sure, that this task includes the searched document.
-        // It's time to activate it. As special feature we try to jump internaly
+        // It's time to activate it. As special feature we try to jump internally
         // if an optional jumpmark is given too.
         if (m_aURL.Mark.getLength())
             impl_jumpToMark(xResult, m_aURL);
diff --git a/main/framework/source/recording/dispatchrecordersupplier.cxx b/main/framework/source/recording/dispatchrecordersupplier.cxx
index b520191..ca0153f 100644
--- a/main/framework/source/recording/dispatchrecordersupplier.cxx
+++ b/main/framework/source/recording/dispatchrecordersupplier.cxx
@@ -145,7 +145,7 @@ void SAL_CALL DispatchRecorderSupplier::setDispatchRecorder( const css::uno::Ref
 /**
     @short      provides access to the dispatch recorder of this supplier
     @descr      Such recorder can be used outside to record dispatches.
-                But normally he is used internaly only. Of course he must used
+                But normally he is used internally only. Of course he must be used
                 from outside to get the recorded data e.g. for saving it as a
                 script.
 
diff --git a/main/framework/source/services/autorecovery.cxx b/main/framework/source/services/autorecovery.cxx
index 31bcf89..fa309c1 100644
--- a/main/framework/source/services/autorecovery.cxx
+++ b/main/framework/source/services/autorecovery.cxx
@@ -627,7 +627,7 @@ void SAL_CALL AutoRecovery::dispatch(const css::util::URL&
     // This can be done immediately ... must not been done asynchronous.
     if ((eNewJob & AutoRecovery::E_DISABLE_AUTORECOVERY) == AutoRecovery::E_DISABLE_AUTORECOVERY)
     {
-        // it's important to set a flag internaly, so AutoRecovery will be suppressed - even if it's requested.
+        // it's important to set a flag internally, so AutoRecovery will be suppressed - even if it's requested.
         m_eJob |= eNewJob;
         implts_stopTimer();
         implts_stopListening();
@@ -977,8 +977,8 @@ void SAL_CALL AutoRecovery::changesOccurred(const css::util::ChangesEvent& aEven
     // <- SAFE ----------------------------------
 
     // Note: This call stops the timer and starts it again.
-    // But it checks the different timer states internaly and
-    // may be suppress the restart!
+    // But it checks the different timer states internally and
+    // may suppress the restart!
     implts_updateTimer();
 }
 
diff --git a/main/framework/source/services/backingcomp.cxx b/main/framework/source/services/backingcomp.cxx
index 6c38ec7..61ee10c 100644
--- a/main/framework/source/services/backingcomp.cxx
+++ b/main/framework/source/services/backingcomp.cxx
@@ -599,7 +599,7 @@ void SAL_CALL BackingComp::restoreViewData( /*IN*/ const css::uno::Any& )
 
     @see    attachFrame()
 
-    @return The internaly saved frame reference.
+    @return The internally saved frame reference.
             Can be null, if attachFrame() was not called before.
  */
 
diff --git a/main/framework/source/services/frame.cxx b/main/framework/source/services/frame.cxx
index a35e93e..42f8077 100644
--- a/main/framework/source/services/frame.cxx
+++ b/main/framework/source/services/frame.cxx
@@ -2344,10 +2344,10 @@ aEvent
 void SAL_CALL Frame::windowClosing( const css::lang::EventObject& ) throw( css::uno::RuntimeException )
 {
     /* #i62088#
-        Some interceptor objects intercept our "internaly asynchronoues implemented" dispatch call.
+        Some interceptor objects intercept our "internally asynchronoues implemented" dispatch call.
         And they close this frame directly (means synchronous then).
         Means: Frame::windowClosing()->Frame::close()
-        In such situation its not a good idea to hold this transaction count alive .-)
+        In such situation it's not a good idea to hold this transaction count alive .-)
     */
     {
         // Look for rejected calls.
diff --git a/main/framework/source/services/modulemanager.cxx b/main/framework/source/services/modulemanager.cxx
index c8e97d5..b0c76dc 100644
--- a/main/framework/source/services/modulemanager.cxx
+++ b/main/framework/source/services/modulemanager.cxx
@@ -392,8 +392,8 @@ css::uno::Reference< css::container::XNameAccess > ModuleManager::implts_getConf
 ::rtl::OUString ModuleManager::implts_identify(const css::uno::Reference< css::uno::XInterface >& xComponent)
 {
     // Search for an optional (!) interface XModule first.
-    // Its used to overrule an existing service name. Used e.g. by our database form designer
-    // which uses a writer module internaly.
+    // It's used to overrule an existing service name. Used e.g. by our database form designer
+    // which uses a writer module internally.
     css::uno::Reference< css::frame::XModule > xModule(xComponent, css::uno::UNO_QUERY);
     if (xModule.is())
         return xModule->getIdentifier();
diff --git a/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java b/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java
index ce243f1..cc6c607 100644
--- a/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java
+++ b/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java
@@ -246,13 +246,13 @@ public class CustomizeView extends    JPanel
 
         /**
          * callback for disposing events
-         * Internaly we save a reference to an office frame.
+         * Internally we save a reference to an office frame.
          * Of course he can die and inform us then. We should react
          * and forget his reference.
          *
          * @param aEvent
          *          describes the source which fire this event
-         *          Must be our internal saved frame. Otherwhise
+         *          Must be our internal saved frame. Otherwise
          *          somewhere know us without a registration ...
          */
         public void disposing(com.sun.star.lang.EventObject aEvent)
diff --git a/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java b/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java
index cc88ccb..3e739c3 100644
--- a/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java
+++ b/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java
@@ -47,7 +47,7 @@ import java.util.Vector;
  * Another reason for such extra class for listening:
  * Most listener callbacks are asynchronoues [oneay] requests.
  * And it's not allowed to call back synchronously there.
- * So we must start threads for updating something internaly.
+ * So we must start threads for updating something internally.
  *
  * @author     Andreas Schl&uuml;ns
  * @created    15.07.2002 12:36
diff --git a/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java b/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
index 3509cb0..c4a15f3 100644
--- a/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
+++ b/main/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
@@ -200,7 +200,7 @@ public class StatusView extends    JPanel
      * Set new frame for this view and start listening for events imedatly.
      * We create one status listener for every control we whish to update.
      * And because the environment of the frame can be changed - these
-     * listener refresh himself internaly for frame action events too.
+     * listener refresh himself internally for frame action events too.
      * So we register it as such frame action listener only here.
      * Rest is done automatically ...
      *
diff --git a/main/offapi/com/sun/star/document/FilterFactory.idl b/main/offapi/com/sun/star/document/FilterFactory.idl
index eaf988c..fc4f96c 100644
--- a/main/offapi/com/sun/star/document/FilterFactory.idl
+++ b/main/offapi/com/sun/star/document/FilterFactory.idl
@@ -67,7 +67,7 @@ published service FilterFactory
         <p>
         <strong>Current behaviour</strong><p>
         The methods createInstance() or createInstanceWithArguments() of this interface must be
-        called with an internal type name!. This name is used internaly to search a suitable
+        called with an internal type name!. This name is used internally to search a suitable
         (mostly the default) filter for this type then. The found filter will be created, initialized
         and returned then. Creation of a filter by using it's internal filter name directly can be
         reached by using createInstanceWithArguments() with an optional property "FilterName" only.
diff --git a/main/offapi/com/sun/star/frame/DispatchRecorderSupplier.idl b/main/offapi/com/sun/star/frame/DispatchRecorderSupplier.idl
index 9a04080..4502565 100644
--- a/main/offapi/com/sun/star/frame/DispatchRecorderSupplier.idl
+++ b/main/offapi/com/sun/star/frame/DispatchRecorderSupplier.idl
@@ -37,7 +37,7 @@
     <p>
     This supplier regulate macro recording of <member>XDispatch::dispatch()</member>
     calls. For that it capsulate a reference to a <type>DispatchRecorder</type>.
-    Such recorder is used internaly and can be used externaly too.
+    Such recorder is used internally and can be used externally too.
     A supplier will be available on a <type>Frame</type> if recording was enabled,
     otherwise not. A frame supports a special property for that.
     This modular concept of recorder, supplier and frame makes it possible to
diff --git a/main/offapi/com/sun/star/frame/XDispatchRecorderSupplier.idl b/main/offapi/com/sun/star/frame/XDispatchRecorderSupplier.idl
index dbcc5a3..f222cb9 100644
--- a/main/offapi/com/sun/star/frame/XDispatchRecorderSupplier.idl
+++ b/main/offapi/com/sun/star/frame/XDispatchRecorderSupplier.idl
@@ -76,7 +76,7 @@ published interface XDispatchRecorderSupplier: com::sun::star::uno::XInterface
 
         <p>
         Returned recorder can be used to record dispatches manualy or to get
-        recorded data for further using e.g. saving. He is internaly used too
+        recorded data for further using e.g. saving. He is internally used too
         due to the method <member>XDispatchRecorderSupplier::dispatchAndRecord()</member>.
         </p>
 
@@ -91,7 +91,7 @@ published interface XDispatchRecorderSupplier: com::sun::star::uno::XInterface
     /** dispatch given URL and record it if recording is enabled
 
         <p>
-        Parameter <var>Dispatcher</var> is used internaly to make the dispatch.
+        Parameter <var>Dispatcher</var> is used internally to make the dispatch.
         If recording isn't enabled it will be a normal <member>XDispatch::dispatch()</member>
         call. Otherwise follow algorithm is used:
         <ul>
diff --git a/main/sd/inc/Outliner.hxx b/main/sd/inc/Outliner.hxx
index 82c40b5..acb0aa9 100644
--- a/main/sd/inc/Outliner.hxx
+++ b/main/sd/inc/Outliner.hxx
@@ -165,7 +165,7 @@ public:
     void StartConversion( sal_Int16 nSourceLanguage,  sal_Int16 nTargetLanguage, 
                 const Font *pTargetFont, sal_Int32 nOptions, sal_Bool bIsInteractive );
 
-    /** This is called internaly when text conversion is started.
+    /** This is called internally when text conversion is started.
 		The position of current view mode/page/object/caret position
 		is remembered and will be restored after conversion.
     */
diff --git a/main/sfx2/source/appl/sfxhelp.cxx b/main/sfx2/source/appl/sfxhelp.cxx
index dd8dbe0..8a50781 100644
--- a/main/sfx2/source/appl/sfxhelp.cxx
+++ b/main/sfx2/source/appl/sfxhelp.cxx
@@ -840,7 +840,7 @@ SfxHelpWindow_Impl* impl_createHelp(Reference< XFrame >& rHelpTask   ,
         xParentWindow->setVisible(sal_True);
         xHelpWindow->setVisible(sal_True);
 
-        // This sub frame is created internaly (if we called new SfxHelpWindow_Impl() ...)
+        // This sub frame is created internally (if we called new SfxHelpWindow_Impl() ...)
         // It should exist :-)
         xHelpContent = xHelpTask->findFrame(::rtl::OUString(DEFINE_CONST_UNICODE("OFFICE_HELP")), FrameSearchFlag::CHILDREN);
     }
diff --git a/main/svtools/inc/svtools/filectrl.hxx b/main/svtools/inc/svtools/filectrl.hxx
index 39570bf..0e22141 100644
--- a/main/svtools/inc/svtools/filectrl.hxx
+++ b/main/svtools/inc/svtools/filectrl.hxx
@@ -98,7 +98,7 @@ public:
 	void			ResetButtonText();
 						  
 	//------
-	//use this to manipulate the dialog bevore executing it:
+	//use this to manipulate the dialog before executing it:
 	void			SetDialogCreatedHdl( const Link& rLink ) { maDialogCreatedHdl = rLink; }
 	const Link& 	GetDialogCreatedHdl() const { return maDialogCreatedHdl; }
 };
diff --git a/main/svx/source/inc/svxrectctaccessiblecontext.hxx b/main/svx/source/inc/svxrectctaccessiblecontext.hxx
index b623604..7bf7f74 100644
--- a/main/svx/source/inc/svxrectctaccessiblecontext.hxx
+++ b/main/svx/source/inc/svxrectctaccessiblecontext.hxx
@@ -248,7 +248,7 @@ protected:
     /** Selects a new child by index.
 
         <p>If the child was not selected before, the state of the child will
-        be updated. If the index is invalid, the index will internaly set to NOCHILDSELECTED</p>
+        be updated. If the index is invalid, the index will internally set to NOCHILDSELECTED</p>
 
         @param nIndexOfChild
             Index of the new child which should be selected.
@@ -260,7 +260,7 @@ public:
     /** Selects a new child by point.
 
         <p>If the child was not selected before, the state of the child will
-        be updated. If the point is not invalid, the index will internaly set to NOCHILDSELECTED</p>
+        be updated. If the point is not invalid, the index will internally set to NOCHILDSELECTED</p>
 
         @param eButton
             Button which belongs to the child which should be selected.
diff --git a/main/svx/source/unodraw/recoveryui.cxx b/main/svx/source/unodraw/recoveryui.cxx
index d585e7c..bb78a2e 100644
--- a/main/svx/source/unodraw/recoveryui.cxx
+++ b/main/svx/source/unodraw/recoveryui.cxx
@@ -103,7 +103,7 @@ css::uno::Any SAL_CALL RecoveryUI::dispatchWithReturnValue(const css::util::URL&
                                                    const css::uno::Sequence< css::beans::PropertyValue >& )
     throw(css::uno::RuntimeException)
 {
-    // Internaly we use VCL ... every call into vcl based code must
+    // Internally we use VCL ... every call into vcl based code must
     // be guarded by locking the global solar mutex.
     ::vos::OGuard aSolarLock(&Application::GetSolarMutex());
diff --git a/main/framework/inc/dispatch/closedispatcher.hxx b/main/framework/inc/dispatch/closedispatcher.hxx
index 97f7159..7fb3aba 100644
--- a/main/framework/inc/dispatch/closedispatcher.hxx
+++ b/main/framework/inc/dispatch/closedispatcher.hxx
@@ -109,7 +109,7 @@ class CloseDispatcher : public css::lang::XTypeProvider
 
         //---------------------------------------
         /** @short  used for asynchronous callbacks within the main thread.
-            @descr  Internaly we work asynchronous. Because our callis
+            @descr  Internally we work asynchronous. Because our calls
                     are not aware, that her request can kill its own environment ... */
         ::vcl::EventPoster m_aAsyncCallback;
 
@@ -127,7 +127,7 @@ class CloseDispatcher : public css::lang::XTypeProvider
         ListenerHash m_lStatusListener;
 
         //---------------------------------------
         /** @short  holded alive for internaly asynchronous operations! */
         css::uno::Reference< css::frame::XDispatchResultListener > m_xResultListener;
 
     //-------------------------------------------
@@ -137,13 +137,13 @@ class CloseDispatcher : public css::lang::XTypeProvider
 
         //---------------------------------------
         /** @short  connect a new CloseDispatcher instance to its frame.
-            @descr  One CloseDispatcher instance is bound to onw frame only.
+            @descr  One CloseDispatcher instance is bound to own frame only.
                     That makes an implementation (e.g. of listener support)
                     much more easier .-)
 
             @param  xSMGR
-                    an un oservice manager, which is needed to create uno resource
-                    internaly.
+                    an uno service manager, which is needed to create uno resource
+                    internally.
 
             @param  xFrame
                     the frame where the corresponding dispatch was started.
@@ -196,8 +196,8 @@ class CloseDispatcher : public css::lang::XTypeProvider
         //---------------------------------------
         /** @short  a callback for asynchronous started operations.
 
-            @descr  As already mentione, we make internaly all operations
-                    asynchronous. Otherwhise our callis kill its own environment
+            @descr  As already mentioned, we make internally all operations
+                    asynchronous. Otherwise our calls kill its own environment
                     during they call us ...
         */
         DECL_LINK( impl_asyncCallback, void* );
@@ -127,7 +127,7 @@ class CloseDispatcher : public css::lang::XTypeProvider
 
         //---------------------------------------
-        /** @short  holded alive for internaly asynchronous operations! */
+        /** @short  held alive for internally asynchronous operations! */
         css::uno::Reference< css::frame::XDispatchResultListener > m_xResultListener;
 
diff --git a/main/framework/source/inc/accelerators/presethandler.hxx b/main/framework/source/inc/accelerators/presethandler.hxx
index 6459117..bb55e86 100644
--- a/main/framework/source/inc/accelerators/presethandler.hxx
+++ b/main/framework/source/inc/accelerators/presethandler.hxx
@@ -248,7 +248,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
                     can't have any special parameters!
                     
             @param  xSMGR
-                    points to an uno service manager, which is used internaly
+                    points to an uno service manager, which is used internally
                     to create own needed uno resources.                    
          */
         PresetHandler(const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR);      
@@ -266,7 +266,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
         void forgetCachedStorages();
         
         //---------------------------------------
         /** @short  return access to the internaly used and cached root storage.
         
             @descr  These root storages are the base of all further opened
                     presets and targets. They are provided here only, to support
@@ -274,7 +274,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
                     
                     getOrCreate...() - What does it mean?
                     Such root storage will be created one times only and
-                    cached then internaly till the last instance of such PresetHandler
+                    cached then internally till the last instance of such PresetHandler
                     dies.
                     
             @return com::sun::star::embed::XStorage
@@ -334,7 +334,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
                     
                     Localzation will be represented as directory structure
                     of provided presets. Means: you call us with a preset name "default";
-                    and we use e.g. "/en-US/default.xml" internaly.
+                    and we use e.g. "/en-US/default.xml" internally.
                     
                     If no localization exists for this preset set, this class
                     will work in default mode - means "no locale" - automatically.
@@ -266,7 +266,7 @@ class PresetHandler : private ThreadHelpBase // attention! Must be the first bas
         
         //---------------------------------------
-        /** @short  return access to the internaly used and cached root storage.
+        /** @short  return access to the internally used and cached root storage.
         
             @descr  These root storages are the base of all further opened